API
========================================================

data\_readiness
-------------------------------------------------------

.. automodule:: geochemistrypi.data_mining.data.data_readiness
   :members:
   :undoc-members:
   :show-inheritance:

feature\_engineering
------------------------------------------------------------

.. automodule:: geochemistrypi.data_mining.data.feature_engineering
   :members:
   :undoc-members:
   :show-inheritance:

data.imputation
--------------------------------------------------

.. automodule:: geochemistrypi.data_mining.data.imputation
   :members:
   :undoc-members:
   :show-inheritance:

data.preprocessing
-----------------------------------------------------

.. automodule:: geochemistrypi.data_mining.data.preprocessing
   :members:
   :undoc-members:
   :show-inheritance:

data.statistic
-------------------------------------------------

.. automodule:: geochemistrypi.data_mining.data.statistic
   :members:
   :undoc-members:
   :show-inheritance:
